@@ -374,6 +374,8 @@ class CommandDecorator:
 
         def factory(func):
             _args = args
+            help = None
+            desc = None
             if func.__doc__ is not None:
                 _doc = func.__doc__
 
@@ -387,9 +389,15 @@ class CommandDecorator:
                         desc = ''
                 else:
                     desc = _doc
-            else:
-                help = None
-                desc = None
+
+            if 'preprocessor' in opts:
+                func._argdeco_preprocessor = opts.pop('preprocessor')
+
+            if 'compile' in opts:
+                func._argdeco_compile = opts.pop('compile')
+
+            if 'compiler_factory' in opts:
+                func._argdeco_compiler_factory = opts.pop('compiler_factory')
 
             if desc is not None:
                 desc = dedent(desc)
@@ -432,16 +440,34 @@ class CommandDecorator:
         if argv is None:
             argv = sys.argv[1:]
 
+        import argcomplete
+        argcomplete.autocomplete(self.argparser)
+        args = self.argparser.parse_args(argv)
+
+        try:
+            action = args.action
+        except AttributeError:
+            action = self.default_action
+
         # initialize arg processors
         if not preprocessor:
             preprocessor = self.preprocessor
 
+        if hasattr(action, '_argdeco_preprocessor'):
+            preprocessor = action._argdeco_preprocessor
+
         if not compile:
             compile = self.compile
 
+        if hasattr(action, '_argdeco_compile'):
+            preprocessor = action._argdeco_compile
+
         if not compiler_factory:
             compiler_factory = self.compiler_factory
 
+        if hasattr(action, '_argdeco_compiler_factory'):
+            preprocessor = action._argdeco_compiler_factory
+
         assert not (compiler_factory and compile), \
             "you can either define a compiler factory or a compile function"
 
@@ -451,15 +477,6 @@ class CommandDecorator:
         if compiler_factory:
             compile = compiler_factory(self)
 
-        import argcomplete
-        argcomplete.autocomplete(self.argparser)
-        args = self.argparser.parse_args(argv)
-
-        try:
-            action = args.action
-        except AttributeError:
-            action = self.default_action
-
         if preprocessor:
             result = None
             try:
